@@ -10,14 +10,27 @@
 #' \code{\link{getBIENpoints}} results.
 #'
 #' @keywords internal
+#' @noRd
 
-GBIFtableCleanup <- function(GBIFtable){
-
+GBIFtableCleanup <- function(GBIFtable) {
   isnothing <- function(x) {
-    any(is.null(x))  | any(is.na(x)  | sum(apply(x,2,is.nan)) > 0)
+    any(is.null(x)) | any(is.na(x) | sum(apply(x, 2, is.nan)) > 0)
   }
 
-  if (is.null(nrow(GBIFtable))){
+  if (is.null(nrow(GBIFtable))) {
+    GBIFtable <- NULL
+    GBIFtable["name"] <- NA
+    GBIFtable["longitude"] <- NA
+    GBIFtable["latitude"] <- NA
+    GBIFtable["day"] <- NA
+    GBIFtable["month"] <- NA
+    GBIFtable["year"] <- NA
+    GBIFtable["Dataset"] <- NA
+    GBIFtable["DatasetKey"] <- NA
+    GBIFtable["DataService"] <- NA
+    GBIFtable <- as.data.frame(as.list(GBIFtable))
+    return(GBIFtable)
+  } else if (nrow(GBIFtable) == 0) {
     GBIFtable <- NULL
     GBIFtable["name"] <- NA
     GBIFtable["longitude"] <- NA
@@ -31,8 +44,8 @@ GBIFtableCleanup <- function(GBIFtable){
     GBIFtable <- as.data.frame(as.list(GBIFtable))
     return(GBIFtable)
   } else {
-    if (!isnothing(GBIFtable)){
-      GBIFtable <- GBIFtable[,-1]
+    if (!isnothing(GBIFtable)) {
+      GBIFtable <- GBIFtable[, -1]
       GBIFtable["name"] <- as.factor(unlist(GBIFtable["name"]))
       GBIFtable["longitude"] <- as.numeric(unlist(GBIFtable["longitude"]))
       GBIFtable["latitude"] <- as.numeric(unlist(GBIFtable["latitude"]))
